TsaiBorderTokens class final

Border-width values sourced from Penpot.

Annotations

Constructors

TsaiBorderTokens({required double hairline})
Creates border tokens.
const

Properties

hairline double
One-pixel border.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerp(TsaiBorderTokens other, double t) TsaiBorderTokens
Interpolates every border-width value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited