TsaiTextButton class final
Two-size Inter button label from the Tsai typography system.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TsaiText
- TsaiTextButton
Constructors
- TsaiTextButton(String data, {required TsaiButtonTextSize size, Key? key, Color? color, TextAlign? textAlign, TextOverflow? overflow, int? maxLines, bool? softWrap, TextScaler? textScaler, String? semanticsLabel})
-
Creates an Inter button label.
const
Properties
- color → Color?
-
Optional semantic color override.
finalinherited
- data → String
-
Text to display.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxLines → int?
-
Maximum number of displayed lines.
finalinherited
- overflow → TextOverflow?
-
How visual overflow is handled.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
Accessibility label that replaces data in semantics.
finalinherited
- size → TsaiButtonTextSize
-
Typography size.
final
- softWrap → bool?
-
Whether the text may wrap at soft line breaks.
finalinherited
- textAlign → TextAlign?
-
How the text is aligned horizontally.
finalinherited
- textScaler → TextScaler?
-
Optional text scaling strategy.
finalinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited