TsaiPinInput class
A PIN input rendered as Penpot PIN dots.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TsaiPinInput
Constructors
-
TsaiPinInput({Key? key, TextEditingController? controller, String? initialValue, int length = 4, FocusNode? focusNode, bool enabled = true, bool autofocus = false, bool isError = false, bool isSuccess = false, ValueChanged<
String> ? onChanged, ValueChanged<String> ? onCompleted, ValueChanged<String> ? onSubmitted, ValueChanged<bool> ? onFocusChange, String semanticLabel = 'PIN'}) -
Creates a Tsai PIN input.
const
Properties
- autofocus → bool
-
Whether the input requests focus initially.
final
- controller → TextEditingController?
-
Optional caller-owned controller containing digits only.
final
- enabled → bool
-
Whether the sequence accepts input.
final
- focusNode → FocusNode?
-
Optional caller-owned focus node.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → String?
-
Initial digits used when controller is null.
final
- isError → bool
-
Whether every dot uses the error color.
final
- isSuccess → bool
-
Whether every dot uses the success color.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- length → int
-
Number of 12-pixel dots.
final
-
onChanged
→ ValueChanged<
String> ? -
Called whenever the user changes the sequence.
final
-
onCompleted
→ ValueChanged<
String> ? -
Called when every dot is filled with a new complete sequence.
final
-
onFocusChange
→ ValueChanged<
bool> ? -
Called when keyboard focus changes.
final
-
onSubmitted
→ ValueChanged<
String> ? -
Called when the user submits the sequence.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String
-
Accessibility label for the editable sequence.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited